All files in this 'ontology_matching' folder were originally created by Explosion.AI and originally licensed under MIT (see the LICENSE file in this folder).

These have since been modified as part of the KAZU repo, and are now licensed under Apache 2.0 as part of the repo as a whole (see the top-level LICENSE file).

test_ontology_matching.py is not in this folder, but in the same situation (i.e. originally authored by Explosion.AI and originally MIT licensed).

Finally, some elements of the below files are taken from the same Explosion.AI codebase, but have been futher modified, and the larger file is originally authored by the Kazu authors:

* steps/ner/explosion.py
* ontology_preprocessing/base.py
